==> kolourpaint-17.03.90.tar.xz: kolourpaint-17.03.90/tools/kpToolColorPicker.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef KP_TOOL_COLOR_PICKER_H
#define KP_TOOL_COLOR_PICKER_H


#include "imagelib/kpColor.h"
#include "tools/kpTool.h"


class QPoint;
class QRect;


class kpToolColorPicker : public kpTool
{
Q_OBJECT

public:
    kpToolColorPicker (kpToolEnvironment *environ, QObject *parent);
    virtual ~kpToolColorPicker ();

    // generally the user goes to pick a color but wants to return to using
    // his/her previous drawing tool
    virtual bool returnToPreviousToolAfterEndDraw () const { return true; }

private:
    kpColor colorAtPixel (const QPoint &p);

    QString haventBegunDrawUserMessage () const;

public:
    virtual void begin ();
    virtual void beginDraw ();
    virtual void draw (const QPoint &thisPoint, const QPoint &, const QRect &);
    virtual void cancelShape ();
    virtual void releasedAllButtons ();
    virtual void endDraw (const QPoint &thisPoint, const QRect &);

private:
    kpColor m_oldColor;
};


#endif  // KP_TOOL_COLOR_PICKER_H

==> kolourpaint-22.04.1.tar.xz: kolourpaint-22.04.1/tools/kpToolColorPicker.h <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#ifndef KP_TOOL_COLOR_PICKER_H
#define KP_TOOL_COLOR_PICKER_H


#include "imagelib/kpColor.h"
#include "tools/kpTool.h"


class QPoint;
class QRect;


class kpToolColorPicker : public kpTool
{
Q_OBJECT

public:
    kpToolColorPicker (kpToolEnvironment *environ, QObject *parent);
    ~kpToolColorPicker () override;

    // generally the user goes to pick a color but wants to return to using
    // his/her previous drawing tool
    bool returnToPreviousToolAfterEndDraw () const override { return true; }

private:
    kpColor colorAtPixel (const QPoint &p);

    QString haventBegunDrawUserMessage () const;

public:
    void begin () override;
    void beginDraw () override;
    void draw (const QPoint &thisPoint, const QPoint &, const QRect &) override;
    void cancelShape () override;
    void releasedAllButtons () override;
    void endDraw (const QPoint &thisPoint, const QRect &) override;

private:
    kpColor m_oldColor;
};


#endif  // KP_TOOL_COLOR_PICKER_H
